@@ -224,7 +224,7 @@ string_file_size_brief (file_entry *fe, int len)
     static char buffer [BUF_TINY];
 
     if (S_ISDIR (fe->buf.st_mode)){
-       strcpy (buffer, (strcmp (fe->fname, "..") ? "SUB-DIR" : "UP--DIR"));
+       strcpy (buffer, _(strcmp (fe->fname, "..") ? N_("SUB-DIR") : N_("UP--DIR")));
        return buffer;
     }
 
@@ -2112,12 +2112,11 @@ do_enter_on_file_entry (file_entry *fe)
 		{
 			char *tmp = name_quote (fe->fname, 0);
 			char *cmd = g_strconcat (".", PATH_SEP_STR, tmp, NULL);
+			g_free (tmp);
 			if (!confirm_execute || (query_dialog (_(" The Midnight Commander "),
 							       _(" Do you really want to execute? "),
 							       0, 2, _("Yes"), _("No")) == 0))
 				execute (cmd);
-
-			g_free (tmp);
 			g_free (cmd);
 		}
 #ifdef USE_VFS
@@ -2160,11 +2159,11 @@ do_enter_on_file_entry (file_entry *fe)
 	    {
 	        char *tmp = name_quote (fe->fname, 0);
 	        char *cmd = g_strconcat (".", PATH_SEP_STR, tmp, NULL);
+	        g_free (tmp);
 	        if (!confirm_execute || (query_dialog (_(" The Midnight Commander "),
 						       _(" Do you really want to execute? "),
 						       0, 2, _("&Yes"), _("&No")) == 0))
 	            execute (cmd);
-	        g_free (tmp);
 	        g_free (cmd);
 	    }
 #ifdef USE_VFS
@@ -2268,7 +2267,7 @@ chdir_to_readlink (WPanel *panel)
     }
 }
 
-static key_map panel_keymap [] = {
+static const key_map panel_keymap [] = {
     { KEY_DOWN,   move_down },
     { KEY_UP, 	move_up },
 
@@ -2386,6 +2385,8 @@ panel_key (WPanel *panel, int key)
     return 0;
 }
 
+void user_file_menu_cmd (void) { user_menu_cmd (NULL); }
+
 static int
 panel_callback (Dlg_head *h, WPanel *panel, int msg, int par)
 {
@@ -2393,7 +2394,7 @@ panel_callback (Dlg_head *h, WPanel *panel, int msg, int par)
     case WIDGET_INIT:
 #ifdef HAVE_X
 	define_label (h, (Widget *)panel, 1, _("Help"), help_cmd);
-	define_label (h, (Widget *)panel, 2, _("Menu"), user_menu_cmd);
+	define_label (h, (Widget *)panel, 2, _("Menu"), user_file_menu_cmd);
 	define_label (h, (Widget *)panel, 3, _("View"), view_panel_cmd);
 	define_label (h, (Widget *)panel, 4, _("Edit"), edit_panel_cmd);
 	define_label (h, (Widget *)panel, 5, _("Copy"), copy_cmd);
@@ -2414,7 +2415,7 @@ panel_callback (Dlg_head *h, WPanel *panel, int msg, int par)
 #endif
 	panel->active = 1;
 	if (mc_chdir (panel->cwd) != 0){
-	    message (1, _(" Error "), _(" Can't chdir to %s \n %s "),
+	    message (1, MSG_ERROR, _(" Can't chdir to \"%s\" \n %s "),
 		     panel->cwd, unix_error_string (errno));
 	} else
 	    subshell_chdir (panel->cwd);
@@ -2423,7 +2424,7 @@ panel_callback (Dlg_head *h, WPanel *panel, int msg, int par)
 	focus_select_item (panel);
 #ifndef HAVE_X
 	define_label (h, (Widget *)panel, 1, _("Help"), help_cmd);
-	define_label (h, (Widget *)panel, 2, _("Menu"), user_menu_cmd);
+	define_label (h, (Widget *)panel, 2, _("Menu"), user_file_menu_cmd);
 	define_label (h, (Widget *)panel, 3, _("View"), view_panel_cmd);
 	define_label (h, (Widget *)panel, 4, _("Edit"), edit_panel_cmd);
 	define_label (h, (Widget *)panel, 5, _("Copy"), copy_cmd);
