@@ -28,7 +28,7 @@
 
 /* }}} */
 
-/*  [] = "$Id: wtools.c,v 1.17 1999/03/24 12:17:08 unammx Exp $" */
+/*  [] = "$Id: wtools.c,v 1.18 1999/04/16 05:53:48 norbert Exp $" */
 
 #include <config.h>
 #include <string.h>
@@ -327,7 +327,7 @@ Dlg_head *message (int error, char *header, char *text, ...)
     /* Setup the display information */
     strcpy (buffer, "\n");
     va_start (args, text);
-    vsprintf (&buffer [1], text, args);
+    g_vsnprintf (&buffer [1], sizeof (buffer), text, args);
     strcat (buffer, "\n");
     va_end (args);
     
