@@ -6,7 +6,7 @@
    Written by: 1998 Pavel Machek
    Spaces fix: 2000 Michal Svec
 
-   $Id: fish.c,v 1.25 2000/03/29 13:36:55 pavel Exp $
+   $Id: fish.c,v 1.27 2000/04/10 12:00:43 pavel Exp $
 
    Derived from ftpfs.c.
    
@@ -268,30 +268,43 @@ open_archive_int (vfs *me, vfs_s_super *super)
 static int
 open_archive (vfs *me, vfs_s_super *super, char *archive_name, char *op)
 {
-    char *host, *user, *password;
+    char *host, *user, *password, *p;
     int flags;
 
-    vfs_split_url (strchr(op, ':')+1, &host, &user, &flags, &password, 0, URL_NOSLASH);
-    SUP.host = g_strdup (host);
-    SUP.user = g_strdup (user);
+    p = vfs_split_url (strchr(op, ':')+1, &host, &user, &flags, &password, 0, URL_NOSLASH);
+
+    if (p)
+	g_free (p);
+
+    SUP.host = host;
+    SUP.user = user;
     SUP.flags = flags;
     if (!strncmp( op, "rsh:", 4 ))
 	SUP.flags |= FISH_FLAG_RSH;
     SUP.home = NULL;
     if (password)
-	SUP.password = g_strdup (password);
+	SUP.password = password;
     return open_archive_int (me, super);
 }
 
 static int
 archive_same(vfs *me, vfs_s_super *super, char *archive_name, char *op, void *cookie)
 {	
-    char *host, *user, *dummy2;
+    char *host, *user;
     int flags;
-    vfs_split_url (strchr(op, ':')+1, &host, &user, &flags, &dummy2, 0, URL_NOSLASH);
-    return ((strcmp (host, SUP.host) == 0) &&
+
+    op = vfs_split_url (strchr(op, ':')+1, &host, &user, &flags, 0, 0, URL_NOSLASH);
+
+    if (op)
+	g_free (op);
+
+    flags = ((strcmp (host, SUP.host) == 0) &&
 	    (strcmp (user, SUP.user) == 0) &&
 	    (flags == SUP.flags));
+    g_free (host);
+    g_free (user);
+
+    return flags;
 }
 
 int
@@ -514,7 +527,7 @@ static int linear_start(vfs *me, vfs_s_fh *fh, int offset)
     name = vfs_s_fullpath (me, fh->ino);
     if (!name)
 	return 0;
-    if (command(me, FH_SUPER, WANT_STRING, 
+    offset = command(me, FH_SUPER, WANT_STRING,
 		"#RETR /%s\n"
 		"ls -l \"/%s\" | (\n"
 		  "read var1 var2 var3 var4 var5 var6\n"
@@ -523,8 +536,9 @@ static int linear_start(vfs *me, vfs_s_fh *fh, int offset)
 		"echo '### 100'\n"
 		"cat \"/%s\"\n"
 		"echo '### 200'\n", 
-		name, name, name )
-	!= PRELIM) ERRNOR (E_REMOTE, 0);
+		name, name, name );
+    g_free (name);
+    if (offset != PRELIM) ERRNOR (E_REMOTE, 0);
     fh->linear = LS_LINEAR_OPEN;
     fh->u.fish.got = 0;
     if (sscanf( reply_str, "%d", &fh->u.fish.total )!=1)
